#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-streams
version:              0.8.9.9
visibility:           public
id:                   http-streams-0.8.9.9-D6q2JqBHs1o4aw5Crq17iZ
key:                  http-streams-0.8.9.9-D6q2JqBHs1o4aw5Crq17iZ
license:              BSD-3-Clause
copyright:            © 2012-2023 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/aesiniath/http-streams/
synopsis:             An HTTP client using io-streams
description:
    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    handle the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.

    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.

category:             Web, IO-Streams
abi:                  64cf03381ff4d7166ad53d2744a47159
exposed:              True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser

hidden-modules:       Network.Http.Utilities
import-dirs:          /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http-streams-0.8.9.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-streams
hs-libraries:         HShttp-streams-0.8.9.9-D6q2JqBHs1o4aw5Crq17iZ
depends:
    HsOpenSSL-0.11.7.9-Ek0WvIsZyHy3lOVt2hjCyN
    aeson-2.2.1.0-HnfSu9AKfZzFhPBHWndcTt
    attoparsec-0.14.4-FWHL4j3hm4w7OAb6a2dq6Z
    attoparsec-aeson-2.2.0.0-BzO58g81OoNGFsYEU5EaJH base-4.18.2.1
    base64-bytestring-1.2.1.0-D5rWQjtzjME1gNikBvBvL
    blaze-builder-0.4.4.1-FYNuD9u6a8N9Y4Gg0dDbwR bytestring-0.11.5.3
    case-insensitive-1.2.1.0-GnOJAdyFoN9CEG6vEkYfx directory-1.3.8.5
    filepath-1.4.300.1 http-common-0.8.3.4-2ai1ujDjK3x854JrDyfJxx
    io-streams-1.5.2.2-JAPzGEMCS1ZBppLVOv1qNP mtl-2.3.1
    network-3.1.4.0-KfjlNjVlGG85uIUjnrRE8N
    network-uri-2.6.4.2-5BhbH0Z6X1TIpLC2mwzRGv
    openssl-streams-1.2.3.0-7FCERRZjCYr579uulq3d0G text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-50KuqheKibtHrVzrLcPiuM

haddock-interfaces:
    /usr/share/doc/haskell-http-streams/html/http-streams.haddock

haddock-html:         /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

